@@ -659,13 +659,16 @@ class RedshiftDialect(PGDialect_psycopg2):
     def _get_column_info(self, *args, **kwargs):
         kw = kwargs.copy()
         encode = kw.pop('encode', None)
-        if sa_version < Version('1.2.0'):
-            # SQLAlchemy 1.2.0 introduced the 'comment' param
-            del kw['comment']
         if sa_version >= Version('1.3.16'):
             # SQLAlchemy 1.3.16 introduced generated columns,
             # not supported in redshift
             kw['generated'] = ''
+
+        if sa_version < Version('1.4.0') and 'identity' in kw:
+            del kw['identity']
+        elif sa_version >= Version('1.4.0') and 'identity' not in kw:
+            kw['identity'] = None
+
         column_info = super(RedshiftDialect, self)._get_column_info(
             *args,
             **kw
@@ -694,12 +697,15 @@ class RedshiftDialect(PGDialect_psycopg2):
 
     def _get_redshift_columns(self, connection, table_name, schema=None, **kw):
         info_cache = kw.get('info_cache')
-        all_columns = self._get_all_column_info(connection,
-                                                info_cache=info_cache)
+        all_schema_columns = self._get_schema_column_info(
+            connection,
+            schema,
+            info_cache=info_cache
+        )
         key = RelationKey(table_name, schema, connection)
-        if key not in all_columns.keys():
+        if key not in all_schema_columns.keys():
             key = key.unquoted()
-        return all_columns[key]
+        return all_schema_columns[key]
 
     def _get_redshift_constraints(self, connection, table_name,
                                   schema=None, **kw):
@@ -741,10 +747,17 @@ class RedshiftDialect(PGDialect_psycopg2):
             relations[key] = rel
         return relations
 
+    # We fetch column info an entire schema at a time to improve performance
+    # when reflecting schema for multiple tables at once.
     @reflection.cache
-    def _get_all_column_info(self, connection, **kw):
+    def _get_schema_column_info(
+        self, connection, schema=None, **kw
+    ):
+        schema_clause = (
+            "AND schema = '{schema}'".format(schema=schema) if schema else ""
+        )
         all_columns = defaultdict(list)
-        with connection.contextual_connect() as cc:
+        with connection.connect() as cc:
             result = cc.execute("""
             SELECT
               n.nspname as "schema",
@@ -773,6 +786,7 @@ class RedshiftDialect(PGDialect_psycopg2):
             WHERE n.nspname !~ '^pg_'
               AND att.attnum > 0
               AND NOT att.attisdropped
+              {schema_clause}
             UNION
             SELECT
               view_schema as "schema",
@@ -796,8 +810,10 @@ class RedshiftDialect(PGDialect_psycopg2):
               col_name name,
               col_type varchar,
               col_num int)
+            WHERE 1 {schema_clause}
             ORDER BY "schema", "table_name", "attnum";
-            """)
+            """.format(schema_clause=schema_clause)
+            )
             for col in result:
                 key = RelationKey(col.table_name, col.schema, connection)
                 all_columns[key].append(col)
@@ -918,17 +934,26 @@ def visit_delete_stmt(element, compiler, **kwargs):
     #   the tables in the using clause are sorted in the order in
     #   which they first appear in the where clause.
     delete_stmt_table = compiler.process(element.table, asfrom=True, **kwargs)
-    whereclause_tuple = element.get_children()
-    if whereclause_tuple:
-        usingclause_tables = []
-        whereclause = ' WHERE {clause}'.format(
-            clause=compiler.process(*whereclause_tuple, **kwargs)
-        )
 
+    if sa_version >= Version('1.4.0'):
+        if element.whereclause is not None:
+            clause = compiler.process(element.whereclause, **kwargs)
+            if clause:
+                whereclause = ' WHERE {clause}'.format(clause=clause)
+    else:
+        whereclause_tuple = element.get_children()
+        if whereclause_tuple:
+            whereclause = ' WHERE {clause}'.format(
+                clause=compiler.process(*whereclause_tuple, **kwargs)
+            )
+
+    if whereclause:
+        usingclause_tables = []
         whereclause_columns = gen_columns_from_children(element)
         for col in whereclause_columns:
             table = compiler.process(col.table, asfrom=True, **kwargs)
-            if table != delete_stmt_table and table not in usingclause_tables:
+            if table != delete_stmt_table and \
+                    table not in usingclause_tables:
                 usingclause_tables.append(table)
         if usingclause_tables:
             usingclause = ' USING {clause}'.format(
